#!/usr/local/bin/tixwish4.1.8.0
#!/mpiwork/tools/T4/bin/et_wish4.0 -f
#!/EPICS/epics/bin/et_wish -f
#!/usr/local/bin/et_wish -f
#
# ======================================================================
#
# ======================================================================
# ===  Control-Script for the CCD-Kamera at DSAZ Calar Alto / Spain  ===
# ======================================================================
#	
#	Abstract:  Designed for Exposure Series
#	           Such as Flat & Dark Field Series or fast Photometrie 
#	
#	Usage:     CCD_Exposure_Series_GUI.tcl
#
#	Tools:     This Tcl/Tk Script is based on the official 
#	           DSAZ CCD-Camera control command.
#
#	See also:  Documentation for the CCD-Camera System 
#	           External Commands
#	           http://www.mpia-hd.mpg.de/CAHA/
#	           --> Instruments  --> CCD detectors  --> Commands 
#
#	Authors:   J.L. Deetjen  &  S. Dreizler
#	           Institut for Astronomy and Astrophysics 
#                   University Tuebingen / Germany
#   
#	Date:      May 1998
#
#	Bugs &               Please send us a mail.
#	Improved Versions:   Deetjen@astro.uni-tuebingen.de
#   
#	Warning:   THIS GUI IS NOT OFFICIALY SUPORTED BY THE DSAZ !
#
#	
#	Desciptions: - Tcl / Tk Graphical User Interface  basing on 
#	               wish version 4.0.
#                     - This GUI uses the offical external CCD-Camera 
#	               control command to communicate with the 
#	               Main-CCD-GUI.
# 	             - Only the object name is updated inside the 
#	               exposure loop. All other parameters (e.g. exposure time) 
#                      can be changed with the Main-CCD-GUI during the run.                   
#	             - Attention: The output file name has to be changed
#	               in the Main-CCD-GUI, because there is now external 
#	               CCD-Camera control command for this task.
#	             - Attention: The sliders to select the CCD arrea of 
#	               interest show always the maximal CCD chip size 
#	               without binning. Only the rulers switch to the
#	               new min/max position (after a double-click). 
#
#       Installation:  One has only to adjust the absolut paths given
#                      in the Defenition Section of the tcl-Script.
#
#	Truble Shooting: - Comunication problems with the Main-CCD-GUI
#	                   started by "start_ccd" my be solved by 
#	                   resetting the Main-GUI.
#
#	                 - It's highly recomended to use the 'normal'
#	                   readout speed. The 'fast' mode seems to be 
#	                   buggy. ( Sometimes only the first quarter 
#	                   will be read out. )
#	
# ======================================================================
#
# ======================================================================

# ----------------------------------------------------------------------
#    Defenition Section
# ----------------------------------------------------------------------

# ---> I/O Parameters ---
set fileName            /disk-a/obs22/cameraScript/parFiles/default.pf
set iterations          1
set MAXITERATIONS       1000
set ITERATIONSINTERVAL  [expr $MAXITERATIONS / 5]
set MAXEXPTIME          100
set TIMEINTERVAL        [expr $MAXEXPTIME / 5]

# ---> Abortion flag --
set exit                0

# ---> CCD-Camera Script Command Variables ---
set hbin        1
set vbin        1
set x1          2
set x2          2168
set xmax        2168
set xsize       2168 
set y1          1
set y2          2048
set ymax        2048
set ysize       2048
set exptime     1
set exptype     "science"
set objectname  "target "
set expmode     "normal"
set rspeed      0
# ----------------------------------------------------------------------

# ---> Color etc. Settings ---
tk_setPalette background lightgray foreground blue
set MY_FONT "*-helvetica-bold-r-normal--*-120-*"
set MY_BIGFONT "*-helvetica-bold-r-normal--*-140-*"
# ----------------------------------------------------------------------

# ---> Logos Paths ---
set aitlogo  aitlogo.gif
set dsazlogo mpia_logo.gif
# ----------------------------------------------------------------------


# ----------------------------------------------------------------------
#     CODE SECTION
# ----------------------------------------------------------------------


# -------------------- Control CCD-Kamera: Tcl-Job ---
proc CCD_Control { } {

    global exit iterations hbin vbin x1 x2 y1 y2 exptime \
	exptype objectname expmode rspeed

    set iterationsDummy $iterations
    .getpara.mid1.iterations.scale2 config -bg red
    .getpara.bot.start config -bg darkgreen
    .getpara.bot.stop  config -bg red
    update idletasks

    # ---> Set Binning ---
    set s "exec camera_chip1_hbin {$hbin}"
    eval $s
    exec sleep 1
    set s "exec camera_chip1_vbin {$vbin}"
    eval $s
    exec sleep 1
    
    # ---> Set Area of Interest of CCD-Chip ---
    set s "exec camera_chip1_x1 {$x1}"
    eval $s
    exec sleep 1
    set s "exec camera_chip1_x2 {$x2}"
    eval $s
    exec sleep 1
    set s "exec camera_chip1_y1 {$y1}"
    eval $s
    exec sleep 1
    set s "exec camera_chip1_y2 {$y2}"
    eval $s
    exec sleep 1
    
    # ---> Set Time ---
    set s "exec camera_dewar1_exptime {$exptime}"
    eval $s
    exec sleep 1
    
    # ---> Set Type ---
    set s "exec camera_dewar1_exptype {$exptype}"
    eval $s
    exec sleep 1

    # ---> Set Mode ---
    set s "exec camera_expmode {$expmode}"
    eval $s
    exec sleep 1
    
    # ---> Set Readout Speed ---
    set s "exec camera_chip1_rspeed {$rspeed}"
    eval $s
    exec sleep 5
    
    
    # ---> LOOP ---
    for { set i 1 } { $i <= $iterationsDummy } {incr i}  {
	set object "$objectname $i"
	set s "exec camera_objectname \"$object\" "
	eval $s
	exec sleep 1
	
	set s "exec camera_dewar1_start wait"
	eval $s   
	exec sleep 1

	set iterations [expr $iterations - 1]
	update idletasks
	update
	if {$exit == 1} {set exit 0;break}
    }

    set iterations $iterationsDummy
    .getpara.mid1.iterations.scale2 config -bg lightgray
    .getpara.bot.start config -bg red
    .getpara.bot.stop  config -bg blue
    update idletasks
}
# ----------------------------------------------------------------------

# -------------------- Get Parameter: X-GUI ---
proc GetParameter {} {

    global MAXEXPTIME MAXITERATIONS TIMEINTERVAL ITERATIONSINTERVAL \
	    MY_FONT MY_BIGFONT\
	    aitlogo dsazlogo exit\
	    iterations hbin vbin x1 x2 \
	    xmax xsize y1 y2 ymax ysize exptime \
	    exptype objectname expmode rspeed 

    toplevel .getpara
    .getpara configure -bg yellow
    wm title  .getpara "CCD Control Tool"
    wm iconname .getpara "CCD Control"

    # --- Main Frame Strukture ---
    frame .getpara.top  -relief raised -bd 4 
    frame .getpara.mid0 -relief groove -bd 2 
    frame .getpara.mid1 -relief groove -bd 2
    frame .getpara.mid2 -relief groove -bd 2
    frame .getpara.mid3 -relief groove -bd 2
    frame .getpara.bot  -relief raised -bd 4
    pack .getpara.top  -side top -fill both -padx 1m -pady 1m 
    pack .getpara.mid0 .getpara.mid1  .getpara.mid2 .getpara.mid3  \
	    -side top -fill both -padx 1m -pady 1m 
    pack .getpara.bot  -side top -fill both -padx 1m -pady 1m 

    # --- Header ---
    label .getpara.top.welcome1 -text "CCD Camera Control at DSAZ Calar Alto" \
	    -fg yellow -bg blue -font $MY_BIGFONT
    label .getpara.top.welcome2 -text "Designed for Exposure Series" \
	    -fg yellow -bg blue -font $MY_BIGFONT
    pack .getpara.top.welcome1 .getpara.top.welcome2 -fill both

    # --- Edit Paramters ---
    frame .getpara.mid0.object
    pack  .getpara.mid0.object -side top -padx 1m -fill both

    image create photo imageait
    imageait configure -file $aitlogo
    label .getpara.mid0.object.ait -image imageait
    pack .getpara.mid0.object.ait -side left  

    frame .getpara.mid0.object.fr
    pack .getpara.mid0.object.fr -side left  -padx 1m  

    label .getpara.mid0.object.fr.left1 -text "Object Name:" \
	    -font $MY_FONT
    entry .getpara.mid0.object.fr.entr1 -textvariable objectname -width 22 
    pack  .getpara.mid0.object.fr.left1 -fill both -side top -padx 1m 
    pack  .getpara.mid0.object.fr.entr1 -fill both -side top -padx 1m 
    
    image create photo imagedsaz
    imagedsaz configure -file $dsazlogo
    label .getpara.mid0.object.dsaz -image imagedsaz
    pack .getpara.mid0.object.dsaz -side right

    frame .getpara.mid1.time
    pack  .getpara.mid1.time -side top -padx 1m -fill both
    scale .getpara.mid1.time.scale1 -from 0 -to $MAXEXPTIME \
	    -length 400 -variable exptime \
	    -orient horizontal -label "Exposure Time:" \
	    -tickinterval $TIMEINTERVAL -showvalue true \
	    -font $MY_FONT
    pack  .getpara.mid1.time.scale1 -side left

    frame .getpara.mid1.iterations
    pack  .getpara.mid1.iterations -side top -padx 1m  -fill both
    scale .getpara.mid1.iterations.scale2 -from 0 -to $MAXITERATIONS \
	    -length 400 -variable iterations \
	    -orient horizontal -label "Number of Iterations:" \
	    -tickinterval $ITERATIONSINTERVAL -showvalue true \
	    -font $MY_FONT -command {set iterations }
    pack  .getpara.mid1.iterations.scale2 -side left

    frame .getpara.mid2.bin
    pack  .getpara.mid2.bin -side top -padx 1m  -fill both
    scale .getpara.mid2.bin.scale1 -from 1 -to 5 -length 200 -variable hbin \
	    -orient horizontal -label "Horizontal binning:" \
	    -tickinterval 1 -showvalue true \
	    -font $MY_FONT  
    bind  .getpara.mid2.bin.scale1 <Button-1> {set tmp [expr $xsize / $hbin];  \
	     set x2 $tmp; set x1 0; update; update idletasks }
    pack  .getpara.mid2.bin.scale1 -side left

    scale .getpara.mid2.bin.scale2 -from 1 -to 5 -length 200 -variable vbin \
	    -orient horizontal -label "Vertical binning:" \
	    -tickinterval 1 -showvalue true \
	    -font $MY_FONT  
    bind  .getpara.mid2.bin.scale2 <Button-1> {set tmp [expr $ysize / $vbin];  \
	     set y2 $tmp; set y1 0; update; update idletasks }
    pack  .getpara.mid2.bin.scale2 -side left

    frame .getpara.mid2.x
    pack  .getpara.mid2.x -side top -padx 1m  -fill both
    scale .getpara.mid2.x.scale1 -from 2 -to $xmax -length 200 -variable x1 \
	    -orient horizontal -label "CCD-Chip x1-Value:" \
	    -tickinterval 500 -showvalue true \
	    -font $MY_FONT 
    pack  .getpara.mid2.x.scale1 -side left
    scale .getpara.mid2.x.scale2 -from 2 -to $xmax -length 200 -variable x2 \
	    -orient horizontal -label "CCD-Chip x2-Value:" \
	    -tickinterval 500 -showvalue true \
	    -font $MY_FONT 
    pack  .getpara.mid2.x.scale2 -side left

    frame .getpara.mid2.y
    pack  .getpara.mid2.y -side top -padx 1m  -fill both
    scale .getpara.mid2.y.scale1 -from 1 -to 2048 -length 200 -variable y1 \
	    -orient horizontal -label "CCD-Chip y1-Value:" \
	    -tickinterval 500 -showvalue true \
	    -font $MY_FONT  -command {set ymax}
    pack  .getpara.mid2.y.scale1 -side left
    scale .getpara.mid2.y.scale2 -from 1 -to 2048 -length 200 -variable y2 \
	    -orient horizontal -label "CCD-Chip y2-Value:" \
	    -tickinterval 500 -showvalue true \
	    -font $MY_FONT  -command {set ymax}
    pack  .getpara.mid2.y.scale2 -side left

    frame .getpara.mid3.mode
    pack .getpara.mid3.mode -side top -padx 1m -fill both
    label .getpara.mid3.mode.l -text "Exposure Mode:" \
	    -font $MY_FONT
    radiobutton .getpara.mid3.mode.test -text " test  " \
	    -variable expmode -value "test" \
	    -font $MY_FONT
    radiobutton .getpara.mid3.mode.normal -text "normal" \
	    -variable expmode -value "normal"  \
	    -font $MY_FONT
    pack .getpara.mid3.mode.l -fill both -side left
    pack .getpara.mid3.mode.normal -fill both -side right
    pack .getpara.mid3.mode.test -fill both -side right


    frame .getpara.mid3.type
    pack .getpara.mid3.type -side top -padx 1m -fill both
    label .getpara.mid3.type.l -text "Exposure Type:" \
	    -font $MY_FONT
    radiobutton .getpara.mid3.type.dark -text "dark  " \
	    -variable exptype -value "dark" \
	    -font $MY_FONT
    radiobutton .getpara.mid3.type.science -text "science  " \
	    -variable exptype -value "science"  \
	    -font $MY_FONT
    radiobutton .getpara.mid3.type.focus -text "  focus" \
	    -variable exptype -value "focus"  \
	    -font $MY_FONT
    pack .getpara.mid3.type.l -fill both -side left
    pack .getpara.mid3.type.focus -fill both -side right
    pack .getpara.mid3.type.dark -fill both -side right
    pack .getpara.mid3.type.science -fill both -side right


    frame .getpara.mid3.rspeed
    pack .getpara.mid3.rspeed -side top -padx 1m  -fill both
    label .getpara.mid3.rspeed.l -text "Readout Speed:" \
	    -font $MY_FONT
    radiobutton .getpara.mid3.rspeed.normal -text "normal  " \
	    -variable rspeed -value 0 \
	    -font $MY_FONT
    radiobutton .getpara.mid3.rspeed.fast   -text " fast   " \
	    -variable rspeed -value 1  \
	    -font $MY_FONT
    radiobutton .getpara.mid3.rspeed.slow   -text "   slow" \
	    -variable rspeed -value 3  \
	    -font $MY_FONT
    pack .getpara.mid3.rspeed.l -fill both -side left
    pack .getpara.mid3.rspeed.slow -fill both -side right
    pack .getpara.mid3.rspeed.fast -fill both -side right
    pack .getpara.mid3.rspeed.normal -fill both -side right


    # --- Bottom Widegts ---
    button .getpara.bot.exit -text "Exit" -command {destroy .getpara; exit} \
	    -fg yellow -bg blue \
	    -font $MY_FONT
    pack .getpara.bot.exit -side right

    button .getpara.bot.load -text "Load" -command {LoadParaFile} \
	    -fg yellow -bg blue \
	    -font $MY_FONT
    pack .getpara.bot.load -side left

    button .getpara.bot.save -text "Save" -command {SaveParaFile} \
	    -fg yellow -bg blue \
	    -font $MY_FONT
    pack .getpara.bot.save -side left

    button .getpara.bot.about -text "About" -command {About} \
	    -fg yellow -bg blue \
	    -font $MY_FONT
    pack .getpara.bot.about -side left

    button .getpara.bot.start -text "Start" -command {CCD_Control} \
	    -fg yellow  -bg red \
	    -font $MY_FONT
    pack .getpara.bot.start -side left

    button .getpara.bot.stop -text "Stop" -command {set exit 1} \
	    -fg yellow  -bg blue \
	    -font $MY_FONT
    pack .getpara.bot.stop -side left
}
# ----------------------------------------------------------------------


# ----------------------------------------------------------------------

# -------------------- Write Parameter File: Tcl-Job ---
proc WriteParaFile {} {

    global fileName iterations hbin vbin x1 x2 y1 y2 exptime \
	exptype objectname expmode rspeed 

    set fileId [open $fileName w]

    set datum [exec date +%d.%m.%y_at_%H:%M]
    set user  [exec whoami]

    # --- Write file header ---
    puts $fileId "#=================================================="
    puts $fileId "#=== Parameter File for the                     ==="
    puts $fileId "#=== Control-Script for the CCD-Kamera          ==="
    puts $fileId "#=== at DSAZ Calar Alto / Spain                 ==="
    puts $fileId "#=== This file contains all Parameter settings  ==="
    puts $fileId "#=================================================="
    puts $fileId "#==> Date of creation: $datum "           
    puts $fileId "#==> Created by: $user "
    puts $fileId "#=================================================="    

    puts $fileId "# "
    puts $fileId "#=== I/O Parameters ==============================="
    puts $fileId [format "%-20s :  %-s" iterations $iterations]
    puts $fileId [format "%-20s :  %-s" hbin $hbin]
    puts $fileId [format "%-20s :  %-s" vbin $vbin]
    puts $fileId [format "%-20s :  %-s" x1 $x1]
    puts $fileId [format "%-20s :  %-s" x2 $x2]
    puts $fileId [format "%-20s :  %-s" y1 $y1]
    puts $fileId [format "%-20s :  %-s" y2 $y2]
    puts $fileId [format "%-20s :  %-s" exptime $exptime]
    puts $fileId [format "%-20s :  %-s" exptype $exptype]
    puts $fileId [format "%-20s :  %-s" objectname "$objectname"]
    puts $fileId [format "%-20s :  %-s" expmode $expmode]
    puts $fileId [format "%-20s :  %-s" rspeed $rspeed]

    puts $fileId "#=================================================="    

    close $fileId
}
# ----------------------------------------------------------------------

# -------------------- Save Parameter File: X-GUI ---
proc SaveParaFile {} {

    global fileName

    toplevel .save
    .save configure -bg yellow
    wm title  .save "Save Parameter File"
    wm iconname .save "Save Parameter File"

    # --- Main Frame Strukture ---
    frame .save.top -relief raised -bd 4
    frame .save.mid -relief raised -bd 2
    frame .save.bot -relief raised -bd 4  	
    pack .save.top .save.mid .save.bot -side top -fill both -padx 1m -pady 1m 

    # --- Header ---
    label .save.top.welcome -text "CCD Camera Control: Save Parameter File" \
	    -fg yellow -bg blue
    pack .save.top.welcome -fill both

    # --- Main Body ---
    frame .save.mid.time
    pack  .save.mid.time -side top -padx 2m -pady 2m -fill both
    label .save.mid.time.left1 -text "Full File Name: "
    label .save.mid.time.mid1  -text "   " 
    entry .save.mid.time.entr1 -textvariable fileName -width 45 
    pack  .save.mid.time.left1 -fill both -side left
    pack  .save.mid.time.mid1  -fill both -side left 
    pack  .save.mid.time.entr1 -fill both -side left
    

    # --- Bottom Widegts ---
    button .save.bot.cancel -text "Cancel" -command {destroy .save} \
	    -fg yellow -bg blue
    pack .save.bot.cancel -side right
    button .save.bot.save -text "Save" -command { WriteParaFile \
	    ; destroy .save} \
	    -fg yellow -bg blue
    pack .save.bot.save -side left
   
}
# ----------------------------------------------------------------------

# -------------------- Read Parameter File: Tcl-Job ---
proc ReadParaFile { } {

    global fileName iterations hbin vbin x1 x2 y1 y2 exptime \
	    exptype objectname expmode rspeed

    if [file exists $fileName] { 
	set fileId [open $fileName r+]

	# --- Read leading comment lines. ---
	gets $fileId line
	while {[string match \#* $line] == 1} {
	    gets $fileId line
	}
	
	# --- Read parameters until next comment line
	scan $line  {%20s :  %s} var1 var2
	set  iterations $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  hbin $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  vbin $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  x1 $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  x2 $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  y1 $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  y2 $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  exptime $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  exptype $var2
	gets $fileId line

	set ind [string first ":" $line ]
	incr ind 3
	set var2 [string range $line $ind end]
	set  objectname $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  expmode $var2
	gets $fileId line

	scan $line  {%20s :  %s} var1 var2
	set  rspeed $var2
	gets $fileId line

	close $fileId
    } 
}
# ----------------------------------------------------------------------

# -------------------- Load Paramter File: X-GUI ---
proc LoadParaFile { } {
    
    global fileName

    toplevel .load
    .load configure -bg yellow
    wm title  .load "Load Parameter File"
    wm iconname .load "Load Parameter File"

    # --- Main Frame Strukture ---
    frame .load.top -relief raised -bd 4
    frame .load.mid -relief raised -bd 2
    frame .load.bot -relief raised -bd 4 	
    pack .load.top .load.mid .load.bot -side top -fill both -padx 1m -pady 1m

    # --- Header ---
    label .load.top.welcome -text "CCD Camera Control: Load Parameter File" \
	    -fg yellow -bg blue
    pack .load.top.welcome -fill both

    # --- Main Body ---
    frame .load.mid.time
    pack  .load.mid.time -side top -padx 2m -pady 2m -fill both
    label .load.mid.time.left1 -text "Full File Name: "
    label .load.mid.time.mid1  -text "   " 
    entry .load.mid.time.entr1 -textvariable fileName -width 45 
    pack  .load.mid.time.left1 -fill both -side left
    pack  .load.mid.time.mid1  -fill both -side left 
    pack  .load.mid.time.entr1 -fill both -side left
    

    # --- Bottom Widegts ---
    button .load.bot.cancel -text "Cancel" -command {destroy .load} \
	    -fg yellow -bg blue
    pack .load.bot.cancel -side right
    button .load.bot.load -text "Load" -command {ReadParaFile \
	    ; destroy .load} \
	    -fg yellow -bg blue
    pack .load.bot.load -side left
}
# ----------------------------------------------------------------------

# -------------------- About Info ---
proc About {} {

    toplevel .about
    wm title .about "CCD Control Tool: About"
    
    frame .about.buttons -relief raised -bd 4
    pack  .about.buttons -side bottom -fill both -padx 1m -pady 1m
    button .about.buttons.dismiss -text "Ok" -command "destroy .about" \
	    -fg yellow -bg blue
    pack .about.buttons.dismiss -side top 

    text .about.text -relief sunken -bd 2 -yscrollcommand ".about.scroll set"\
	    -setgrid 1 -height 30 
    scrollbar .about.scroll -command ".about.text yview"
    pack .about.scroll -side right -fill y
    pack .about.text -expand yes -fill both
    .about.text insert 0.0 \
	    {
	======================================================================
	===  Control-Script for the CCD-Kamera at DSAZ Calar Alto / Spain  ===
	======================================================================
	
	Abstract:  Designed for Exposure Series
	           Such as Flat & Dark Field Series or fast Photometrie 
	
	Usage:     CCD_Exposure_Series_GUI.tcl

	Tools:     This Tcl/Tk Script is based on the official 
	           DSAZ CCD-Camera control command.

	See also:  Documentation for the CCD-Camera System 
	           External Commands
	           http://www.mpia-hd.mpg.de/CAHA/
	           --> Instruments  --> CCD detectors  --> Commands 

	Authors:   J.L. Deetjen  &  S. Dreizler
	           Institut for Astronomy and Astrophysics 
                   University Tuebingen / Germany
   
	Date:      May 1998

	Bugs &               Please send us a mail.
	Improved Versions:   Deetjen@astro.uni-tuebingen.de
   
	Warning:   THIS GUI IS NOT OFFICIALY SUPORTED BY THE DSAZ !

	
	Desciptions: - Tcl / Tk Graphical User Interface  basing on 
	               wish version 4.0.
                     - This GUI uses the offical external CCD-Camera 
	               control command to communicate with the 
	               Main-CCD-GUI.
 	             - Only the object name is updated inside the 
	               exposure loop. All other parameters (e.g. exposure time) 
                       can be changed with the Main-CCD-GUI during the run. 
	             - Attention: The output file name has to be changed
	               in the Main-CCD-GUI, because there is now external 
	               CCD-Camera control command for this task.
	             - Attention: The sliders to select the CCD arrea of 
	               interest show always the maximal CCD chip size 
	               without binning. Only the rulers switch to the
	               new min/max position (after a double-click).


        Installation:  One has only to adjust the absolut paths given
                       in the Defenition Section of the tcl-Script.

	Truble Shooting: - Comunication problems with the Main-CCD-GUI
	                   started by "start_ccd" my be solved by 
	                   resetting the Main-GUI.

	                 - It's highly recomended to use the 'normal'
	                   readout speed. The 'fast' mode seems to be 
	                   buggy. ( Sometimes only the first quarter 
	                   will be read out. )
	
	======================================================================
    }
    .about.text mark set insert 0.0

}
# ----------------------------------------------------------------------

wm withdraw .

GetParameter

# ======================================================================
#    End of Camera Script
# ======================================================================
